#[non_exhaustive]pub enum Nesting {
Flat,
Brackets,
Dots,
}Expand description
How keys are nested.
use std::collections::BTreeMap;
use deser_urlencoded::{DeserializerConfig, Nesting};
type Nested = BTreeMap<String, BTreeMap<String, u32>>;
let value: Nested = deser_urlencoded::from_str("a[b]=1").unwrap();
assert_eq!(value["a"]["b"], 1);
let dots = DeserializerConfig::builder().nesting(Nesting::Dots).build();
let value: Nested = dots.from_str("a.b=1").unwrap();
assert_eq!(value["a"]["b"], 1);
let flat = DeserializerConfig::builder().nesting(Nesting::Flat).build();
let value: BTreeMap<String, u32> = flat.from_str("a[b]=1").unwrap();
assert_eq!(value["a[b]"], 1);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Flat
Keys are not nested, they are taken as they are.
Brackets
Nested keys are in brackets: a[b][0]=1 and a[]=1.
This is how Rails, PHP and the qs library of Node write nested
keys.
Dots
Nested keys are separated with dots: a.b.0=1.